==> S2DaoV1.0.6.zip: s2dao/src/test/org/seasar/dao/impl/DeleteAutoStaticCommandTest.java <==
package test.org.seasar.dao.impl;

import org.seasar.dao.UpdateFailureRuntimeException;
import org.seasar.dao.impl.BeanMetaDataImpl;
import org.seasar.dao.impl.DeleteAutoStaticCommand;
import org.seasar.extension.unit.S2TestCase;

public class DeleteAutoStaticCommandTest extends S2TestCase {

	public DeleteAutoStaticCommandTest(String arg0) {
		super(arg0);
	}

	public void testExecuteTx() throws Exception {
		DeleteAutoStaticCommand cmd = new DeleteAutoStaticCommand(
				getDataSource(), new BeanMetaDataImpl(Employee.class,
						getDatabaseMetaData()));
		Employee emp = new Employee();
		emp.setEmpno(7788);
		emp.setEname("SCOTT");
		Integer count = (Integer) cmd.execute(new Object[] { emp });
		assertEquals("1", new Integer(1), count);
	}

	public void testExecute2Tx() throws Exception {
		DeleteAutoStaticCommand cmd = new DeleteAutoStaticCommand(
				getDataSource(), new BeanMetaDataImpl(Department.class,
						getDatabaseMetaData()));
		Department dept = new Department();
		dept.setDeptno(10);
		Integer count = (Integer) cmd.execute(new Object[] { dept });
		assertEquals("1", new Integer(1), count);
	}

	public void testExecute3Tx() throws Exception {
		DeleteAutoStaticCommand cmd = new DeleteAutoStaticCommand(
				getDataSource(), new BeanMetaDataImpl(Department.class,
						getDatabaseMetaData()));
		Department dept = new Department();
		dept.setDeptno(10);
		dept.setVersionNo(-1);
		try {
			cmd.execute(new Object[] { dept });
			fail("1");
		} catch (UpdateFailureRuntimeException ex) {
			System.out.println(ex);
		}
	}

	public void setUp() {
		include("j2ee.dicon");
	}

	public static void main(String[] args) {
		junit.textui.TestRunner.run(DeleteAutoStaticCommandTest.class);
	}

}

==> S2DaoV1.0.12.zip: s2dao/src/test/org/seasar/dao/impl/DeleteAutoStaticCommandTest.java <==
package test.org.seasar.dao.impl;

import org.seasar.dao.DaoMetaData;
import org.seasar.dao.UpdateFailureRuntimeException;
import org.seasar.dao.impl.BeanMetaDataImpl;
import org.seasar.dao.impl.DaoMetaDataImpl;
import org.seasar.dao.impl.DeleteAutoStaticCommand;
import org.seasar.dao.impl.SelectDynamicCommand;
import org.seasar.extension.jdbc.impl.BasicResultSetFactory;
import org.seasar.extension.unit.S2TestCase;

public class DeleteAutoStaticCommandTest extends S2TestCase {

	public DeleteAutoStaticCommandTest(String arg0) {
		super(arg0);
	}

	public void testExecuteTx() throws Exception {
		DeleteAutoStaticCommand cmd = new DeleteAutoStaticCommand(
				getDataSource(), new BeanMetaDataImpl(Employee.class,
						getDatabaseMetaData()));
		DaoMetaData dmd = new DaoMetaDataImpl(EmployeeAutoDao.class,
				getDataSource(), BasicResultSetFactory.INSTANCE);
		SelectDynamicCommand cmd2 = (SelectDynamicCommand) dmd
				.getSqlCommand("getEmployee");
		Employee emp = (Employee) cmd2.execute(new Object[]{new Integer(7788)});
		Integer count = (Integer) cmd.execute(new Object[] { emp });
		assertEquals("1", new Integer(1), count);
	}

	public void testExecute2Tx() throws Exception {
		DeleteAutoStaticCommand cmd = new DeleteAutoStaticCommand(
				getDataSource(), new BeanMetaDataImpl(Department.class,
						getDatabaseMetaData()));
		Department dept = new Department();
		dept.setDeptno(10);
		Integer count = (Integer) cmd.execute(new Object[] { dept });
		assertEquals("1", new Integer(1), count);
	}

	public void testExecute3Tx() throws Exception {
		DeleteAutoStaticCommand cmd = new DeleteAutoStaticCommand(
				getDataSource(), new BeanMetaDataImpl(Department.class,
						getDatabaseMetaData()));
		Department dept = new Department();
		dept.setDeptno(10);
		dept.setVersionNo(-1);
		try {
			cmd.execute(new Object[] { dept });
			fail("1");
		} catch (UpdateFailureRuntimeException ex) {
			System.out.println(ex);
		}
	}

	public void setUp() {
		include("j2ee.dicon");
	}

	public static void main(String[] args) {
		junit.textui.TestRunner.run(DeleteAutoStaticCommandTest.class);
	}

}
